@@ -4,7 +4,7 @@
  * Project: GGZCards Client
  * Date: 08/14/2000
  * Desc: Routines to handle the Gtk game table
- * $Id: table.c,v 1.106 2002/11/03 03:07:10 jdorje Exp $
+ * $Id: table.c 6983 2005-03-11 07:43:05Z jdorje $
  *
  * Copyright (C) 2000-2002 Brent Hendricks.
  *
@@ -47,11 +47,7 @@
 #include "main.h"
 #include "table.h"
 
-#ifdef GTK2
 PangoFontDescription *fixed_font;
-#else
-GtkRcStyle *fixed_font_style;
-#endif
 
 /* Table data */
 GtkWidget *table = NULL;	/* widget containing the whole table */
@@ -87,9 +83,9 @@ void table_draw_table(GdkPixmap * pixmap, int x, int y, int w, int h)
 		pixmap = table_drawing_area->window;
 
 	/* Display the buffer */
-	gdk_draw_pixmap(pixmap,
-			table_style->fg_gc[GTK_WIDGET_STATE(table)],
-			table_buf, x, y, x, y, w, h);
+	gdk_draw_drawable(pixmap,
+			  table_style->fg_gc[GTK_WIDGET_STATE(table)],
+			  table_buf, x, y, x, y, w, h);
 }
 
 /* FIXME: maybe this function should be dropped... */
@@ -145,10 +141,12 @@ static void table_clear_table(int write_to_screen)
 	/* Clear the buffer to the style's background color */
 	gdk_draw_rectangle(table_buf,
 			   table_style->bg_gc[GTK_WIDGET_STATE(table)],
-			   TRUE, 0, 0, get_table_width(), get_table_height());
+			   TRUE, 0, 0, get_table_width(),
+			   get_table_height());
 
 	if (write_to_screen)
-		table_show_table(0, 0, get_table_width(), get_table_height());
+		table_show_table(0, 0, get_table_width(),
+				 get_table_height());
 }
 
 /* Draws a "splash screen" that is shown before the game is initialized. */
@@ -189,24 +187,23 @@ void table_initialize(void)
 	ggz_debug(DBG_TABLE, "Initializing table.");
 
 	/* This starts our drawing code */
-	table = gtk_object_get_data(GTK_OBJECT(dlg_main), "fixed1");
+	table = g_object_get_data(G_OBJECT(dlg_main), "fixed1");
 	table_style = gtk_widget_get_style(table);
 	gtk_widget_show(table);
 
 	table_drawing_area = gtk_drawing_area_new();
-	gtk_drawing_area_size(GTK_DRAWING_AREA(table_drawing_area),
-			      get_table_width(), get_table_height());
+	gtk_widget_set_size_request(table_drawing_area,
+				    get_table_width(), get_table_height());
 	gtk_fixed_put(GTK_FIXED(table), table_drawing_area, 0, 0);
 	gtk_widget_show(table_drawing_area);
-	(void) gtk_signal_connect(GTK_OBJECT(table_drawing_area),
-				  "expose_event",
-				  GTK_SIGNAL_FUNC(on_table_expose_event),
-				  NULL);
+	g_signal_connect(table_drawing_area, "expose_event",
+			 GTK_SIGNAL_FUNC(on_table_expose_event), NULL);
 
 	assert(table_drawing_area->window);
 	assert(get_table_width() > 0 && get_table_height > 0);
 	table_buf = gdk_pixmap_new(table->window,
-				   get_table_width(), get_table_height(), -1);
+				   get_table_width(), get_table_height(),
+				   -1);
 	assert(table_buf);
 
 	/* Redraw and display the table. */
@@ -246,13 +243,16 @@ void table_setup(void)
 		game_started = TRUE;
 	}
 
-	ggz_debug(DBG_TABLE, "Setting up table." "  Width and height are %d."
-		  "  %d players.", get_table_width(), ggzcards.num_players);
+	ggz_debug(DBG_TABLE,
+		  "Setting up table." "  Width and height are %d."
+		  "  %d players.", get_table_width(),
+		  ggzcards.num_players);
 
 	/* We may need to resize the table */
-	gtk_widget_set_usize(table, get_table_width(), get_table_height());
-	gtk_drawing_area_size(GTK_DRAWING_AREA(table_drawing_area),
-			      get_table_width(), get_table_height());
+	gtk_widget_set_size_request(table, get_table_width(),
+				    get_table_height());
+	gtk_widget_set_size_request(table_drawing_area,
+				    get_table_width(), get_table_height());
 
 	/* And resize the table buffer... */
 	/* Note: I'm not entirely sure how reference counts work for gdk. I
@@ -260,9 +260,10 @@ void table_setup(void)
 	   refcount of 1.  In that case, this code should correctly free the
 	   pixmap when it is discarded. */
 	assert(table_buf);
-	gdk_pixmap_unref(table_buf);
+	g_object_unref(table_buf);
 	table_buf = gdk_pixmap_new(table->window,
-				   get_table_width(), get_table_height(), -1);
+				   get_table_width(), get_table_height(),
+				   -1);
 
 	/* Resize the animation buffer. */
 	anim_setup();
@@ -335,20 +336,25 @@ void table_cleanup(void)
 static void table_show_player_box(int player, int write_to_screen)
 {
 	int x, y, w, h;
-#ifdef GTK2
-	GdkFont *font = gtk_style_get_font(table_style);
-#else
-	GdkFont *font = table_style->font;
-#endif
 	const char *name = player_names[player];
 	const char *message = player_messages[player];
 	int string_y;
 	int max_width = 0;
+	static PangoLayout *layout = NULL;
+	PangoRectangle rect;
+	GdkGC *gc = table_style->fg_gc[GTK_WIDGET_STATE(table)];
 
-	static int max_ascent = 0, max_descent = 0;
+	static int max_height = 0;
 
 	assert(table_ready);
 
+	if (!layout) {
+		/* This variable is static so we only allocate it once. */
+		layout = pango_layout_new(gdk_pango_context_get());
+	}
+
+	pango_layout_set_font_description(layout, table_style->font_desc);
+
 	get_text_box_pos(player, &x, &y);
 	x++;
 	y++;
@@ -356,71 +362,59 @@ static void table_show_player_box(int player, int write_to_screen)
 	/* Clear the text box */
 	gdk_draw_rectangle(table_buf,
 			   table_style->bg_gc[GTK_WIDGET_STATE(table)],
-			   TRUE, x, y, TEXT_BOX_WIDTH - 1, TEXT_BOX_WIDTH - 1);
+			   TRUE, x, y, TEXT_BOX_WIDTH - 1,
+			   TEXT_BOX_WIDTH - 1);
 
 	x += XWIDTH;
 	y += XWIDTH;
 	w = h = TEXT_WIDTH;
 
-	string_y = y;		/* The y values we're going to draw at. */
+	string_y = y;	/* The y values we're going to draw at. */
 
 	/* Draw the name. */
 	if (name) {
-		int ascent, descent, dummy, width;
-
 		assert(strchr(name, '\n') == NULL);
 
-		gdk_string_extents(font, name, &dummy, &dummy,
-				   &width, &ascent, &descent);
-		max_width = MAX(max_width, width);
+		pango_layout_set_text(layout, name, -1);
+		pango_layout_get_pixel_extents(layout, NULL, &rect);
 
-		max_ascent = MAX(max_ascent, ascent);
-		max_descent = MAX(max_descent, descent);
+		max_width = MAX(max_width, rect.width);
+		max_height = MAX(max_height, rect.height);
 
-		string_y += max_ascent;
+		gdk_draw_layout(table_buf, gc,
+				x + (w - rect.width) / 2, string_y,
+				layout);
 
-		gdk_draw_text(table_buf, font,
-			      table_style->fg_gc[GTK_WIDGET_STATE(table)],
-			      x + w / 2 - gdk_string_width(font, name) / 2,
-			      string_y, name, strlen(name));
-
-		string_y += max_descent + 5;
+		string_y += max_height + 5;
 	}
 
 	/* Draw player message. */
 	if (message) {
 		char *my_message = ggz_strdup(message);
 		char *next = my_message;
-		int ascent, descent, dummy;
-
-		gdk_string_extents(font, my_message, &dummy, &dummy,
-				   &dummy, &ascent, &descent);
-
-		max_ascent = MAX(max_ascent, ascent);
-		max_descent = MAX(max_descent, descent);
 
 		/* This is so ugly!! Is there no better way?? */
 		do {
 			char *next_after_this = strchr(next, '\n');
-			int width;
 
 			if (next_after_this) {
 				*next_after_this = '\0';
 				next_after_this++;
 			}
 
-			string_y += 3 + max_ascent;
+			string_y += 3;
 
-			gdk_string_extents(font, next, &dummy, &dummy,
-					   &width, &dummy, &dummy);
-			max_width = MAX(max_width, width);
+			pango_layout_set_text(layout, next, -1);
+			pango_layout_get_pixel_extents(layout, NULL,
+						       &rect);
 
-			gdk_draw_string(table_buf, font,
-					table_style->
-					fg_gc[GTK_WIDGET_STATE(table)], x + 3,
-					string_y, next);
+			max_height = MAX(max_height, rect.height);
+			max_width = MAX(max_width, rect.width);
 
-			string_y += max_descent;
+			gdk_draw_layout(table_buf, gc,
+					x + 3, string_y, layout);
+
+			string_y += rect.height;
 
 			next = next_after_this;
 		} while (next && *next);
@@ -430,18 +424,21 @@ static void table_show_player_box(int player, int write_to_screen)
 
 	/* FIXME: we shouldn't call table_setup() from *within* the drawing
 	   code */
-	if (set_min_text_width(string_y - y) || set_min_text_width(max_width)) {
+	if (set_min_text_width(string_y - y)
+	    || set_min_text_width(max_width)) {
 		table_setup();
 	}
 
 	if (write_to_screen)
-		table_show_table(x, y, TEXT_BOX_WIDTH - 1, TEXT_BOX_WIDTH - 1);
+		table_show_table(x, y, TEXT_BOX_WIDTH - 1,
+				 TEXT_BOX_WIDTH - 1);
 }
 
 /* Display's a player's name on the table. */
 void table_set_name(int player, const char *name)
 {
-	ggz_debug(DBG_TABLE, "Setting player name: %d => %s.", player, name);
+	ggz_debug(DBG_TABLE, "Setting player name: %d => %s.", player,
+		  name);
 
 	if (player_names[player])
 		ggz_free(player_names[player]);
@@ -490,12 +487,13 @@ void table_redraw(void)
 			table_show_player_box(p, FALSE);
 
 		/* Then draw the whole buffer to the window */
-		table_show_table(0, 0, get_table_width(), get_table_height());
+		table_show_table(0, 0, get_table_width(),
+				 get_table_height());
 
 		/* There has GOT to be a better way to force the redraw! */
 		gdk_window_hide(table_drawing_area->window);
 		gdk_window_show(table_drawing_area->window);
-	} else {		/* not if (table_ready) */
+	} else {	/* not if (table_ready) */
 		if (table_buf)
 			draw_splash_screen();
 	}
@@ -533,8 +531,9 @@ gboolean table_handle_cardclick_event(GdkEventButton * event)
 
 	assert(p >= 0 && p < ggzcards.num_players);
 
-	ggz_debug(DBG_TABLE, "table_handle_click_event: " "click at %f %f.",
-		  event->x, event->y);
+	ggz_debug(DBG_TABLE,
+		  "table_handle_click_event: " "click at %f %f.", event->x,
+		  event->y);
 
 	/* This gets all of the layout information from the layout engine.
 	   Unfortunately, it's very dense code. */
@@ -543,8 +542,8 @@ gboolean table_handle_cardclick_event(GdkEventButton * event)
 
 	/* Calculate our card target */
 	hand_size = preferences.collapse_hand
-		? ggzcards.players[p].hand.hand_size
-		: ggzcards.players[p].u_hand_size;
+	    ? ggzcards.players[p].hand.hand_size
+	    : ggzcards.players[p].u_hand_size;
 	for (target = 0; target < hand_size; target++) {
 		int x, y;
 
@@ -571,7 +570,7 @@ gboolean table_handle_cardclick_event(GdkEventButton * event)
 
 
 /* Right-clicking on the table can pop up a menu. */
-gboolean table_handle_menuclick_event(GdkEventButton *event)
+gboolean table_handle_menuclick_event(GdkEventButton * event)
 {
 	int p;
 
@@ -581,15 +580,15 @@ gboolean table_handle_menuclick_event(GdkEventButton *event)
 		int w = get_text_width();
 		int x, y;
 
-		if (seat_num < 0) continue;
+		if (seat_num < 0)
+			continue;
 
 		get_text_box_pos(p, &x, &y);
 		x += XWIDTH;
 		y += XWIDTH;
 		if (event->x < x
 		    || event->x >= x + w
-		    || event->y < y
-		    || event-> y >= y + w)
+		    || event->y < y || event->y >= y + w)
 			continue;
 
 		seat = ggzmod_get_seat(client_get_ggzmod(), seat_num);
@@ -605,7 +604,8 @@ gboolean table_handle_menuclick_event(GdkEventButton *event)
    it is already selected. */
 static void table_card_clicked(int card_num)
 {
-	ggz_debug(DBG_TABLE, "table_card_clicked: Card %d clicked.", card_num);
+	ggz_debug(DBG_TABLE, "table_card_clicked: Card %d clicked.",
+		  card_num);
 
 	if (card_num == selected_card || preferences.single_click_play) {
 		/* If you click on the already selected card, it gets played.
@@ -632,7 +632,7 @@ static void clear_card_area(int p)
 			   TRUE, cx, cy, cw, ch);
 }
 
-static void show_card_area(p)
+static void show_card_area(int p)
 {
 	int cx, cy, cw, ch;
 
@@ -668,8 +668,8 @@ void table_display_hand(int p, int write_to_screen)
 
 	/* Draw the cards */
 	hand_size = preferences.collapse_hand
-		? ggzcards.players[p].hand.hand_size
-		: ggzcards.players[p].u_hand_size;
+	    ? ggzcards.players[p].hand.hand_size
+	    : ggzcards.players[p].u_hand_size;
 	for (i = 0; i < hand_size; i++) {
 		card_t card;
 		int x, y;
